.. highlight:: shell

==============================================================================
Installation
==============================================================================


Stable release
------------------------------------------------------------------------------

To install ML Launchpad, run this command in your terminal:

.. code-block:: console

    $ pipenv install mllaunchpad

Or, if don't use pipenv (why not? It's awesome! 😀):

.. code-block:: console

    $ pip install mllaunchpad

These two are the preferred methods for installing ML Launchpad, as they will
always install the most recent stable release.

We recommend using `pipenv`_ for installing and uninstalling mllaunchpad
and other packages in your project. It automatically manages a
project-folder-level virtual environment and tracks your project's
requirements for you.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------------------------------------------------------------------------

The sources for ML Launchpad can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/schuderer/mllaunchpad

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/schuderer/mllaunchpad/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _pipenv: https://pipenv.readthedocs.io/en/latest/
.. _Github repo: https://github.com/schuderer/mllaunchpad
.. _tarball: https://github.com/schuderer/mllaunchpad/tarball/master
